module.exports = defineTest({
	description: 'handles deoptimization of object properties'
});
